==> antiright-2.99.6.tar.bz2: antiright/gtkshell/add_options.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

extern GtkWidget *gsh_button;

void
gsh_handle_add_arguments(int argc, char **argv, unsigned int *counter)
{
	assert(strlen(argv[(*counter)])>1);
	switch(argv[(*counter)][2])
	{
		case 'b':
			gsh_count(argc, counter);
			{
				GtkWidget *icon_view;
				icon_view=gtk_icon_view_new();
			}
			break;
		case 'I':
			gsh_count(argc, counter);
                gsh_image_button(argv[*counter], argv[*counter+1]);
                	gsh_count(argc, counter);
                	gtk_button_set_label(GTK_BUTTON(gsh_button), "");
                	break;
		case 'i':
			gsh_count(argc, counter);
                	gsh_image_button(argv[(*counter)], argv[(*counter)+1]);
                	gsh_count(argc, counter);
                	break;
		case 'l':
			gsh_count(argc, counter);
			gsh_add_label(argv[(*counter)]);
			break;
		case 'p':
			gsh_count(argc, counter);
                	gsh_setup_prompt_command_entry(argv[(*counter)]);
                	break;
		case 't':
			gsh_count(argc, counter);
			gsh_setup_command_entry(argv[(*counter)]);
			break;
		case 'T':
			gsh_text_area();
			break;
		case 'u':
			gsh_handle_updated_arguments(argc, argv, counter);
			break;
	}
}

==> antiright-2.99.7.tar.bz2: antiright/gtkshell/add_options.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

void
gsh_handle_add_arguments(struct GSH *gsh, int argc, char **argv, int *counter)
{
	assert(strlen(argv[(*counter)])>1);
	switch(argv[(*counter)][2])
	{
        case 'b': /* FIXME: not really implemented.  */
			gsh_count(argc, counter);
			{
				GtkWidget *icon_view;
				icon_view=gtk_icon_view_new();
                /* has to be managed.  */
			}
			break;
		case 'I':
			gsh_count(argc, counter);
            gsh_image_button(gsh, argv[*counter], argv[*counter+1]);
            gsh_count(argc, counter);
            gtk_button_set_label(GTK_BUTTON(gsh->button), "");
            break;
		case 'i':
			gsh_count(argc, counter);
            gsh_image_button(gsh, argv[(*counter)], argv[(*counter)+1]);
            gsh_count(argc, counter);
            break;
		case 'l':
			gsh_count(argc, counter);
			gsh_add_label(gsh, argv[(*counter)]);
			break;
		case 'p':
			gsh_count(argc, counter);
            gsh_setup_prompt_command_entry(gsh, argv[(*counter)]);
            break;
		case 't':
			gsh_count(argc, counter);
			gsh_setup_command_entry(gsh, argv[(*counter)]);
			break;
		case 'T':
			gsh_text_area(gsh);
			break;
		case 'u':
			gsh_handle_updated_arguments(gsh, argc, argv, counter);
			break;
	}
}
